function [Flag,cur_HR]=Determine_B(x,feature_loca,HR_base,Range_base,Amp_base,T_A_be,T_A,Fs)

% $This algorithm was used to detect if the current ICU alarm belongs to the B type (Extreme Bradycardia).
%
% $inputs:
%   x: the signal, column vector.
%   feature loca: detected feature information: for ECG is the R peak location, for pulse is the pusle foot.
%   HR_base: heart rate of the current signal
%   Amp_base: the mean amplitude at the feature points of the current signal.
%   T_A_be: time window
%   T_A: time window for the potential signal segment with A type.
%   Fs: sample frequency
% $output:
%   Flag:  Flag=1 denotes the alarm is true based on the current channel signal.
%
% $Author:  Chengyu Liu; bestlcy@sdu.edu.cn
%           School of Control Science and Engineering,
%           Shandong University
% $Date:    2015.07.01
% $Last update:    2015.07.14

Flag=1;
cur_loca=feature_loca(feature_loca>(T_A_be-T_A)*Fs+1  & feature_loca<T_A_be*Fs);
cur_HR=[];
if ~isempty(cur_loca)
    if length(cur_loca>=3)
        RR_cur=diff(cur_loca);
        RR_cur(RR_cur>3*Fs)=[];
    end
    if ~isempty(RR_cur)
        cur_HR=(60*Fs)/max(RR_cur);
    end
    indx=[];
    for i=1:length(cur_loca)-1
        cur_data=x(cur_loca(i)-round(Fs*0.1):cur_loca(i)+round(Fs*0.15));
        if (abs(x(cur_loca(i))) > 0.5*abs(Amp_base) && abs(x(cur_loca(i))) < 2*abs(Amp_base)) || ((max(cur_data)-min(cur_data)) > 0.5*Range_base &&  (max(cur_data)-min(cur_data)) < 2*Range_base)
            indx=[indx;i];
        end
    end
    if abs(x(cur_loca(end))) > 0.7*abs(Amp_base)
        indx=[indx;length(cur_loca)];
    end
    cur_loca=cur_loca(indx);
    if length(cur_loca)>4
        RR_cur=diff(cur_loca);
        RR_cur=sort(RR_cur);
        if ((60*Fs)/mean(RR_cur(end-3:end)) > 51.5 + 0.06*HR_base - 8 && HR_base > 42)
           Flag=0;
        end
    end   
end

